# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: obplib/OBP.proto

from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.protobuf import any_pb2 as google_dot_protobuf_dot_any__pb2


DESCRIPTOR = _descriptor.FileDescriptor(
  name='obplib/OBP.proto',
  package='OBPprotobuf',
  syntax='proto3',
  serialized_options=b'\252\002\024Openmelt.OBPprotobuf',
  create_key=_descriptor._internal_create_key,
  serialized_pb=b'\n\x10obplib/OBP.proto\x12\x0bOBPprotobuf\x1a\x19google/protobuf/any.proto\"x\n\x08Metadata\x12\x39\n\nattributes\x18\x01 \x03(\x0b\x32%.OBPprotobuf.Metadata.AttributesEntry\x1a\x31\n\x0f\x41ttributesEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\"7\n\x0e\x42\x65\x61mParameters\x12\x11\n\tspot_size\x18\x01 \x01(\x02\x12\x12\n\nbeam_power\x18\x02 \x01(\x02\"r\n\x04Line\x12+\n\x06params\x18\x01 \x01(\x0b\x32\x1b.OBPprotobuf.BeamParameters\x12\n\n\x02x0\x18\x02 \x01(\x01\x12\n\n\x02y0\x18\x03 \x01(\x01\x12\n\n\x02x1\x18\x04 \x01(\x01\x12\n\n\x02y1\x18\x05 \x01(\x01\x12\r\n\x05speed\x18\x06 \x01(\x04\"\x9e\x01\n\x0bTimedPoints\x12+\n\x06params\x18\x01 \x01(\x0b\x32\x1b.OBPprotobuf.BeamParameters\x12\x33\n\x06points\x18\x02 \x03(\x0b\x32#.OBPprotobuf.TimedPoints.TimedPoint\x1a-\n\nTimedPoint\x12\t\n\x01x\x18\x01 \x01(\x01\x12\t\n\x01y\x18\x02 \x01(\x01\x12\t\n\x01t\x18\x03 \x01(\r\"\xfa\x01\n\x05\x43urve\x12+\n\x06params\x18\x01 \x01(\x0b\x32\x1b.OBPprotobuf.BeamParameters\x12$\n\x02p0\x18\x02 \x01(\x0b\x32\x18.OBPprotobuf.Curve.Point\x12$\n\x02p1\x18\x03 \x01(\x0b\x32\x18.OBPprotobuf.Curve.Point\x12$\n\x02p2\x18\x04 \x01(\x0b\x32\x18.OBPprotobuf.Curve.Point\x12$\n\x02p3\x18\x05 \x01(\x0b\x32\x18.OBPprotobuf.Curve.Point\x12\r\n\x05speed\x18\x06 \x01(\x04\x1a\x1d\n\x05Point\x12\t\n\x01x\x18\x01 \x01(\x01\x12\t\n\x01y\x18\x02 \x01(\x01\"\x87\x01\n\x10\x41\x63\x63\x65leratingLine\x12+\n\x06params\x18\x01 \x01(\x0b\x32\x1b.OBPprotobuf.BeamParameters\x12\n\n\x02x0\x18\x02 \x01(\x01\x12\n\n\x02y0\x18\x03 \x01(\x01\x12\n\n\x02x1\x18\x04 \x01(\x01\x12\n\n\x02y1\x18\x05 \x01(\x01\x12\n\n\x02si\x18\x06 \x01(\x04\x12\n\n\x02sf\x18\x07 \x01(\x04\"\xf0\x01\n\x11\x41\x63\x63\x65leratingCurve\x12+\n\x06params\x18\x01 \x01(\x0b\x32\x1b.OBPprotobuf.BeamParameters\x12$\n\x02p0\x18\x02 \x01(\x0b\x32\x18.OBPprotobuf.Curve.Point\x12$\n\x02p1\x18\x03 \x01(\x0b\x32\x18.OBPprotobuf.Curve.Point\x12$\n\x02p2\x18\x04 \x01(\x0b\x32\x18.OBPprotobuf.Curve.Point\x12$\n\x02p3\x18\x05 \x01(\x0b\x32\x18.OBPprotobuf.Curve.Point\x12\n\n\x02si\x18\x06 \x01(\x04\x12\n\n\x02sf\x18\x07 \x01(\x04\"\t\n\x07Restore\">\n\tSyncPoint\x12\x10\n\x08\x65ndpoint\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\x08\x12\x10\n\x08\x64uration\x18\x03 \x01(\x02\"\xc0\x03\n\x06Packet\x12!\n\x04line\x18\n \x01(\x0b\x32\x11.OBPprotobuf.LineH\x00\x12\x30\n\x0ctimed_points\x18\x0b \x01(\x0b\x32\x18.OBPprotobuf.TimedPointsH\x00\x12#\n\x05\x63urve\x18\x0c \x01(\x0b\x32\x12.OBPprotobuf.CurveH\x00\x12:\n\x11\x61\x63\x63\x65lerating_line\x18\r \x01(\x0b\x32\x1d.OBPprotobuf.AcceleratingLineH\x00\x12<\n\x12\x61\x63\x63\x65lerating_curve\x18\x0e \x01(\x0b\x32\x1e.OBPprotobuf.AcceleratingCurveH\x00\x12\x30\n\x10restore_defaults\x18\x15 \x01(\x0b\x32\x14.OBPprotobuf.RestoreH\x00\x12)\n\x08metadata\x18\x16 \x01(\x0b\x32\x15.OBPprotobuf.MetadataH\x00\x12,\n\x0cvendor_setup\x18\x17 \x01(\x0b\x32\x14.google.protobuf.AnyH\x00\x12,\n\nsync_point\x18\x18 \x01(\x0b\x32\x16.OBPprotobuf.SyncPointH\x00\x42\t\n\x07payloadB\x17\xaa\x02\x14Openmelt.OBPprotobufb\x06proto3'
  ,
  dependencies=[google_dot_protobuf_dot_any__pb2.DESCRIPTOR,])




_METADATA_ATTRIBUTESENTRY = _descriptor.Descriptor(
  name='AttributesEntry',
  full_name='OBPprotobuf.Metadata.AttributesEntry',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='key', full_name='OBPprotobuf.Metadata.AttributesEntry.key', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='value', full_name='OBPprotobuf.Metadata.AttributesEntry.value', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=b'8\001',
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=131,
  serialized_end=180,
)

_METADATA = _descriptor.Descriptor(
  name='Metadata',
  full_name='OBPprotobuf.Metadata',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='attributes', full_name='OBPprotobuf.Metadata.attributes', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[_METADATA_ATTRIBUTESENTRY, ],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=60,
  serialized_end=180,
)


_BEAMPARAMETERS = _descriptor.Descriptor(
  name='BeamParameters',
  full_name='OBPprotobuf.BeamParameters',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='spot_size', full_name='OBPprotobuf.BeamParameters.spot_size', index=0,
      number=1, type=2, cpp_type=6, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='beam_power', full_name='OBPprotobuf.BeamParameters.beam_power', index=1,
      number=2, type=2, cpp_type=6, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=182,
  serialized_end=237,
)


_LINE = _descriptor.Descriptor(
  name='Line',
  full_name='OBPprotobuf.Line',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='params', full_name='OBPprotobuf.Line.params', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='x0', full_name='OBPprotobuf.Line.x0', index=1,
      number=2, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='y0', full_name='OBPprotobuf.Line.y0', index=2,
      number=3, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='x1', full_name='OBPprotobuf.Line.x1', index=3,
      number=4, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='y1', full_name='OBPprotobuf.Line.y1', index=4,
      number=5, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='speed', full_name='OBPprotobuf.Line.speed', index=5,
      number=6, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=239,
  serialized_end=353,
)


_TIMEDPOINTS_TIMEDPOINT = _descriptor.Descriptor(
  name='TimedPoint',
  full_name='OBPprotobuf.TimedPoints.TimedPoint',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='x', full_name='OBPprotobuf.TimedPoints.TimedPoint.x', index=0,
      number=1, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='y', full_name='OBPprotobuf.TimedPoints.TimedPoint.y', index=1,
      number=2, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='t', full_name='OBPprotobuf.TimedPoints.TimedPoint.t', index=2,
      number=3, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=469,
  serialized_end=514,
)

_TIMEDPOINTS = _descriptor.Descriptor(
  name='TimedPoints',
  full_name='OBPprotobuf.TimedPoints',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='params', full_name='OBPprotobuf.TimedPoints.params', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='points', full_name='OBPprotobuf.TimedPoints.points', index=1,
      number=2, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[_TIMEDPOINTS_TIMEDPOINT, ],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=356,
  serialized_end=514,
)


_CURVE_POINT = _descriptor.Descriptor(
  name='Point',
  full_name='OBPprotobuf.Curve.Point',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='x', full_name='OBPprotobuf.Curve.Point.x', index=0,
      number=1, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='y', full_name='OBPprotobuf.Curve.Point.y', index=1,
      number=2, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=738,
  serialized_end=767,
)

_CURVE = _descriptor.Descriptor(
  name='Curve',
  full_name='OBPprotobuf.Curve',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='params', full_name='OBPprotobuf.Curve.params', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='p0', full_name='OBPprotobuf.Curve.p0', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='p1', full_name='OBPprotobuf.Curve.p1', index=2,
      number=3, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='p2', full_name='OBPprotobuf.Curve.p2', index=3,
      number=4, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='p3', full_name='OBPprotobuf.Curve.p3', index=4,
      number=5, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='speed', full_name='OBPprotobuf.Curve.speed', index=5,
      number=6, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[_CURVE_POINT, ],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=517,
  serialized_end=767,
)


_ACCELERATINGLINE = _descriptor.Descriptor(
  name='AcceleratingLine',
  full_name='OBPprotobuf.AcceleratingLine',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='params', full_name='OBPprotobuf.AcceleratingLine.params', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='x0', full_name='OBPprotobuf.AcceleratingLine.x0', index=1,
      number=2, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='y0', full_name='OBPprotobuf.AcceleratingLine.y0', index=2,
      number=3, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='x1', full_name='OBPprotobuf.AcceleratingLine.x1', index=3,
      number=4, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='y1', full_name='OBPprotobuf.AcceleratingLine.y1', index=4,
      number=5, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='si', full_name='OBPprotobuf.AcceleratingLine.si', index=5,
      number=6, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='sf', full_name='OBPprotobuf.AcceleratingLine.sf', index=6,
      number=7, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=770,
  serialized_end=905,
)


_ACCELERATINGCURVE = _descriptor.Descriptor(
  name='AcceleratingCurve',
  full_name='OBPprotobuf.AcceleratingCurve',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='params', full_name='OBPprotobuf.AcceleratingCurve.params', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='p0', full_name='OBPprotobuf.AcceleratingCurve.p0', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='p1', full_name='OBPprotobuf.AcceleratingCurve.p1', index=2,
      number=3, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='p2', full_name='OBPprotobuf.AcceleratingCurve.p2', index=3,
      number=4, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='p3', full_name='OBPprotobuf.AcceleratingCurve.p3', index=4,
      number=5, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='si', full_name='OBPprotobuf.AcceleratingCurve.si', index=5,
      number=6, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='sf', full_name='OBPprotobuf.AcceleratingCurve.sf', index=6,
      number=7, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=908,
  serialized_end=1148,
)


_RESTORE = _descriptor.Descriptor(
  name='Restore',
  full_name='OBPprotobuf.Restore',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1150,
  serialized_end=1159,
)


_SYNCPOINT = _descriptor.Descriptor(
  name='SyncPoint',
  full_name='OBPprotobuf.SyncPoint',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='endpoint', full_name='OBPprotobuf.SyncPoint.endpoint', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='value', full_name='OBPprotobuf.SyncPoint.value', index=1,
      number=2, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='duration', full_name='OBPprotobuf.SyncPoint.duration', index=2,
      number=3, type=2, cpp_type=6, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1161,
  serialized_end=1223,
)


_PACKET = _descriptor.Descriptor(
  name='Packet',
  full_name='OBPprotobuf.Packet',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='line', full_name='OBPprotobuf.Packet.line', index=0,
      number=10, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='timed_points', full_name='OBPprotobuf.Packet.timed_points', index=1,
      number=11, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='curve', full_name='OBPprotobuf.Packet.curve', index=2,
      number=12, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='accelerating_line', full_name='OBPprotobuf.Packet.accelerating_line', index=3,
      number=13, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='accelerating_curve', full_name='OBPprotobuf.Packet.accelerating_curve', index=4,
      number=14, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='restore_defaults', full_name='OBPprotobuf.Packet.restore_defaults', index=5,
      number=21, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='metadata', full_name='OBPprotobuf.Packet.metadata', index=6,
      number=22, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='vendor_setup', full_name='OBPprotobuf.Packet.vendor_setup', index=7,
      number=23, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='sync_point', full_name='OBPprotobuf.Packet.sync_point', index=8,
      number=24, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
    _descriptor.OneofDescriptor(
      name='payload', full_name='OBPprotobuf.Packet.payload',
      index=0, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[]),
  ],
  serialized_start=1226,
  serialized_end=1674,
)

_METADATA_ATTRIBUTESENTRY.containing_type = _METADATA
_METADATA.fields_by_name['attributes'].message_type = _METADATA_ATTRIBUTESENTRY
_LINE.fields_by_name['params'].message_type = _BEAMPARAMETERS
_TIMEDPOINTS_TIMEDPOINT.containing_type = _TIMEDPOINTS
_TIMEDPOINTS.fields_by_name['params'].message_type = _BEAMPARAMETERS
_TIMEDPOINTS.fields_by_name['points'].message_type = _TIMEDPOINTS_TIMEDPOINT
_CURVE_POINT.containing_type = _CURVE
_CURVE.fields_by_name['params'].message_type = _BEAMPARAMETERS
_CURVE.fields_by_name['p0'].message_type = _CURVE_POINT
_CURVE.fields_by_name['p1'].message_type = _CURVE_POINT
_CURVE.fields_by_name['p2'].message_type = _CURVE_POINT
_CURVE.fields_by_name['p3'].message_type = _CURVE_POINT
_ACCELERATINGLINE.fields_by_name['params'].message_type = _BEAMPARAMETERS
_ACCELERATINGCURVE.fields_by_name['params'].message_type = _BEAMPARAMETERS
_ACCELERATINGCURVE.fields_by_name['p0'].message_type = _CURVE_POINT
_ACCELERATINGCURVE.fields_by_name['p1'].message_type = _CURVE_POINT
_ACCELERATINGCURVE.fields_by_name['p2'].message_type = _CURVE_POINT
_ACCELERATINGCURVE.fields_by_name['p3'].message_type = _CURVE_POINT
_PACKET.fields_by_name['line'].message_type = _LINE
_PACKET.fields_by_name['timed_points'].message_type = _TIMEDPOINTS
_PACKET.fields_by_name['curve'].message_type = _CURVE
_PACKET.fields_by_name['accelerating_line'].message_type = _ACCELERATINGLINE
_PACKET.fields_by_name['accelerating_curve'].message_type = _ACCELERATINGCURVE
_PACKET.fields_by_name['restore_defaults'].message_type = _RESTORE
_PACKET.fields_by_name['metadata'].message_type = _METADATA
_PACKET.fields_by_name['vendor_setup'].message_type = google_dot_protobuf_dot_any__pb2._ANY
_PACKET.fields_by_name['sync_point'].message_type = _SYNCPOINT
_PACKET.oneofs_by_name['payload'].fields.append(
  _PACKET.fields_by_name['line'])
_PACKET.fields_by_name['line'].containing_oneof = _PACKET.oneofs_by_name['payload']
_PACKET.oneofs_by_name['payload'].fields.append(
  _PACKET.fields_by_name['timed_points'])
_PACKET.fields_by_name['timed_points'].containing_oneof = _PACKET.oneofs_by_name['payload']
_PACKET.oneofs_by_name['payload'].fields.append(
  _PACKET.fields_by_name['curve'])
_PACKET.fields_by_name['curve'].containing_oneof = _PACKET.oneofs_by_name['payload']
_PACKET.oneofs_by_name['payload'].fields.append(
  _PACKET.fields_by_name['accelerating_line'])
_PACKET.fields_by_name['accelerating_line'].containing_oneof = _PACKET.oneofs_by_name['payload']
_PACKET.oneofs_by_name['payload'].fields.append(
  _PACKET.fields_by_name['accelerating_curve'])
_PACKET.fields_by_name['accelerating_curve'].containing_oneof = _PACKET.oneofs_by_name['payload']
_PACKET.oneofs_by_name['payload'].fields.append(
  _PACKET.fields_by_name['restore_defaults'])
_PACKET.fields_by_name['restore_defaults'].containing_oneof = _PACKET.oneofs_by_name['payload']
_PACKET.oneofs_by_name['payload'].fields.append(
  _PACKET.fields_by_name['metadata'])
_PACKET.fields_by_name['metadata'].containing_oneof = _PACKET.oneofs_by_name['payload']
_PACKET.oneofs_by_name['payload'].fields.append(
  _PACKET.fields_by_name['vendor_setup'])
_PACKET.fields_by_name['vendor_setup'].containing_oneof = _PACKET.oneofs_by_name['payload']
_PACKET.oneofs_by_name['payload'].fields.append(
  _PACKET.fields_by_name['sync_point'])
_PACKET.fields_by_name['sync_point'].containing_oneof = _PACKET.oneofs_by_name['payload']
DESCRIPTOR.message_types_by_name['Metadata'] = _METADATA
DESCRIPTOR.message_types_by_name['BeamParameters'] = _BEAMPARAMETERS
DESCRIPTOR.message_types_by_name['Line'] = _LINE
DESCRIPTOR.message_types_by_name['TimedPoints'] = _TIMEDPOINTS
DESCRIPTOR.message_types_by_name['Curve'] = _CURVE
DESCRIPTOR.message_types_by_name['AcceleratingLine'] = _ACCELERATINGLINE
DESCRIPTOR.message_types_by_name['AcceleratingCurve'] = _ACCELERATINGCURVE
DESCRIPTOR.message_types_by_name['Restore'] = _RESTORE
DESCRIPTOR.message_types_by_name['SyncPoint'] = _SYNCPOINT
DESCRIPTOR.message_types_by_name['Packet'] = _PACKET
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

Metadata = _reflection.GeneratedProtocolMessageType('Metadata', (_message.Message,), {

  'AttributesEntry' : _reflection.GeneratedProtocolMessageType('AttributesEntry', (_message.Message,), {
    'DESCRIPTOR' : _METADATA_ATTRIBUTESENTRY,
    '__module__' : 'obplib.OBP_pb2'
    # @@protoc_insertion_point(class_scope:OBPprotobuf.Metadata.AttributesEntry)
    })
  ,
  'DESCRIPTOR' : _METADATA,
  '__module__' : 'obplib.OBP_pb2'
  # @@protoc_insertion_point(class_scope:OBPprotobuf.Metadata)
  })
_sym_db.RegisterMessage(Metadata)
_sym_db.RegisterMessage(Metadata.AttributesEntry)

BeamParameters = _reflection.GeneratedProtocolMessageType('BeamParameters', (_message.Message,), {
  'DESCRIPTOR' : _BEAMPARAMETERS,
  '__module__' : 'obplib.OBP_pb2'
  # @@protoc_insertion_point(class_scope:OBPprotobuf.BeamParameters)
  })
_sym_db.RegisterMessage(BeamParameters)

Line = _reflection.GeneratedProtocolMessageType('Line', (_message.Message,), {
  'DESCRIPTOR' : _LINE,
  '__module__' : 'obplib.OBP_pb2'
  # @@protoc_insertion_point(class_scope:OBPprotobuf.Line)
  })
_sym_db.RegisterMessage(Line)

TimedPoints = _reflection.GeneratedProtocolMessageType('TimedPoints', (_message.Message,), {

  'TimedPoint' : _reflection.GeneratedProtocolMessageType('TimedPoint', (_message.Message,), {
    'DESCRIPTOR' : _TIMEDPOINTS_TIMEDPOINT,
    '__module__' : 'obplib.OBP_pb2'
    # @@protoc_insertion_point(class_scope:OBPprotobuf.TimedPoints.TimedPoint)
    })
  ,
  'DESCRIPTOR' : _TIMEDPOINTS,
  '__module__' : 'obplib.OBP_pb2'
  # @@protoc_insertion_point(class_scope:OBPprotobuf.TimedPoints)
  })
_sym_db.RegisterMessage(TimedPoints)
_sym_db.RegisterMessage(TimedPoints.TimedPoint)

Curve = _reflection.GeneratedProtocolMessageType('Curve', (_message.Message,), {

  'Point' : _reflection.GeneratedProtocolMessageType('Point', (_message.Message,), {
    'DESCRIPTOR' : _CURVE_POINT,
    '__module__' : 'obplib.OBP_pb2'
    # @@protoc_insertion_point(class_scope:OBPprotobuf.Curve.Point)
    })
  ,
  'DESCRIPTOR' : _CURVE,
  '__module__' : 'obplib.OBP_pb2'
  # @@protoc_insertion_point(class_scope:OBPprotobuf.Curve)
  })
_sym_db.RegisterMessage(Curve)
_sym_db.RegisterMessage(Curve.Point)

AcceleratingLine = _reflection.GeneratedProtocolMessageType('AcceleratingLine', (_message.Message,), {
  'DESCRIPTOR' : _ACCELERATINGLINE,
  '__module__' : 'obplib.OBP_pb2'
  # @@protoc_insertion_point(class_scope:OBPprotobuf.AcceleratingLine)
  })
_sym_db.RegisterMessage(AcceleratingLine)

AcceleratingCurve = _reflection.GeneratedProtocolMessageType('AcceleratingCurve', (_message.Message,), {
  'DESCRIPTOR' : _ACCELERATINGCURVE,
  '__module__' : 'obplib.OBP_pb2'
  # @@protoc_insertion_point(class_scope:OBPprotobuf.AcceleratingCurve)
  })
_sym_db.RegisterMessage(AcceleratingCurve)

Restore = _reflection.GeneratedProtocolMessageType('Restore', (_message.Message,), {
  'DESCRIPTOR' : _RESTORE,
  '__module__' : 'obplib.OBP_pb2'
  # @@protoc_insertion_point(class_scope:OBPprotobuf.Restore)
  })
_sym_db.RegisterMessage(Restore)

SyncPoint = _reflection.GeneratedProtocolMessageType('SyncPoint', (_message.Message,), {
  'DESCRIPTOR' : _SYNCPOINT,
  '__module__' : 'obplib.OBP_pb2'
  # @@protoc_insertion_point(class_scope:OBPprotobuf.SyncPoint)
  })
_sym_db.RegisterMessage(SyncPoint)

Packet = _reflection.GeneratedProtocolMessageType('Packet', (_message.Message,), {
  'DESCRIPTOR' : _PACKET,
  '__module__' : 'obplib.OBP_pb2'
  # @@protoc_insertion_point(class_scope:OBPprotobuf.Packet)
  })
_sym_db.RegisterMessage(Packet)


DESCRIPTOR._options = None
_METADATA_ATTRIBUTESENTRY._options = None
# @@protoc_insertion_point(module_scope)



# SPDX-FileCopyrightText: 2019,2020 Freemelt AB
#
# SPDX-License-Identifier: Apache-2.0

# Built-in
import sys

# PyPI
import setuptools


with open("README.md", "r") as fh:
    description = fh.read()

sys.path.append('obplib')
from _version import __version__
sys.path.remove('obplib')

setuptools.setup(
    name='obplib',
    version=__version__,
    license="apache-2.0", 
    author="Freemelt AB",
    author_email="opensource@freemelt.com",
    description="A library for the creation of beam paths",
    long_description=description,
    long_description_content_type="text/markdown",
    url="https://gitlab.com/freemelt/openmelt/obplib-python",
    download_url = "https://gitlab.com/freemelt/openmelt/obplib-python/-/archive/0.1.0/obplib-python-0.1.0.tar.gz",
    keywords = "obp openbeampath freemelt",
    packages=setuptools.find_packages(exclude=['tests']),
    install_requires=[
        'protobuf',
        'grpcio',
        # 'grpcio-tools',  # Only used in CI
        ],
    classifiers=[
        "Development Status :: 3 - Alpha",
        "Intended Audience :: Developers",
        "Programming Language :: Python :: 3",
        "License :: OSI Approved :: Apache Software License",
        "Operating System :: OS Independent",
    ],

)
